@@ -4,7 +4,7 @@ use warnings;
 use Cwd;
 use Carp ();
 
-our $VERSION = '0.9030';
+our $VERSION = '0.9031';
 
 sub new {
     my($class, $file) = @_;
@@ -255,41 +255,28 @@ sub feature {
 
 sub osname { die "TODO" }
 
-sub requirement_for {
-    my ($self, $module, @args) = @_;
-
-    my $requirement = 0;
-    $requirement = shift @args if @args % 2;
-
-    return Module::CPANfile::Requirement->new(
-        name    => $module,
-        version => $requirement,
-        @args,
-    );
-}
-
 sub requires {
-    my($self, $module, @args) = @_;
+    my($self, $module, $requirement) = @_;
     ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{requires}{$module} = $self->requirement_for($module, @args);
+      ->{$self->{phase}}{requires}{$module} = $requirement || 0;
 }
 
 sub recommends {
-    my($self, $module, @args) = @_;
+    my($self, $module, $requirement) = @_;
     ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{recommends}{$module} = $self->requirement_for($module, @args);
+      ->{$self->{phase}}{recommends}{$module} = $requirement || 0;
 }
 
 sub suggests {
-    my($self, $module, @args) = @_;
+    my($self, $module, $requirement) = @_;
     ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{suggests}{$module} = $self->requirement_for($module, @args);
+      ->{$self->{phase}}{suggests}{$module} = $requirement || 0;
 }
 
 sub conflicts {
-    my($self, $module, @args) = @_;
+    my($self, $module, $requirement) = @_;
     ($self->{feature} ? $self->{feature}{spec} : $self->{spec})
-      ->{$self->{phase}}{conflicts}{$module} = $self->requirement_for($module, @args);
+      ->{$self->{phase}}{conflicts}{$module} = $requirement || 0;
 }
 
 # Module::Install compatible shortcuts
@@ -314,41 +301,6 @@ sub author_requires {
     $self->on(develop => sub { $self->requires(@args) });
 }
 
-package Module::CPANfile::Requirement;
-use strict;
-use overload '""' => \&as_string, fallback => 1;
-
-sub as_string { shift->{version} }
-
-sub as_hashref {
-    my $self = shift;
-    return +{ %$self };
-}
-
-sub new {
-    my ($class, %args) = @_;
-
-    # requires 'Plack';
-    # requires 'Plack', '0.9970';
-    # requires 'Plack', git => 'git://github.com/plack/Plack.git', rev => '0.9970';
-    # requires 'Plack', '0.9970', git => 'git://github.com/plack/Plack.git', rev => '0.9970';
-
-    $args{version} ||= 0;
-
-    bless +{
-        name    => $args{name},
-        version => $args{version},
-        (exists $args{git} ? (git => $args{git}) : ()),
-        (exists $args{rev} ? (rev => $args{rev}) : ()),
-    }, $class;
-}
-
-sub name    { shift->{name} }
-sub version { shift->{version} }
-
-sub git { shift->{git} }
-sub rev { shift->{rev} }
-
 package Module::CPANfile;
 
 1;
